@@ -138,6 +138,8 @@ my %dirs;
 sub _load {
     my ( $file, $dir ) = @_;
     $file =~ s/\.pm$// || return;    # we only care about .pm files
+    $file =~ s{\\}{/}g;              # to make win32 happy
+    $dir  =~ s{\\}{/}g;              # to make win32 happy
     $file =~ s/^$dir//;
     my $_package = join '::' => grep $_ => File::Spec->splitdir($file);
 
